==> basketball_reference_web_scraper-4.10.0.tar.gz: basketball_reference_web_scraper-4.10.0/README.md <==
<p align="center">
    <a href="#" target="_blank" rel="noopener noreferrer">
        <img width="550" src="https://imgur.com/dJL05Ud.png" alt="logo">
    </a>
</p>
<p align="center">
    <a href="https://pypi.org/project/basketball-reference-scraper/">
        <img src="https://img.shields.io/pypi/v/basketball_reference_web_scraper" alt="pypi" />
    </a>
    <a href="https://pypi.org/project/basketball-reference-scraper/">
        <img src="https://img.shields.io/pypi/pyversions/basketball_reference_web_scraper" alt="python version" />
    </a>
    <a href="https://pypi.org/project/basketball-reference-scraper/">
        <img src="https://img.shields.io/pypi/l/basketball_reference_web_scraper" alt="license" />
    </a>
    <a href="https://codecov.io/gh/jaebradley/basketball_reference_web_scraper">
        <img src="https://codecov.io/gh/jaebradley/basketball_reference_web_scraper/branch/v4/graph/badge.svg" alt="code coverage" />
    </a>
    <a href="https://github.com/jaebradley/basketball_reference_web_scraper/workflows/Basketball%20Reference%20Web%20Scraper/badge.svg">
        <img src="https://github.com/jaebradley/basketball_reference_web_scraper/workflows/Basketball%20Reference%20Web%20Scraper/badge.svg" alt="continuous integration" />
    </a>
</p>

[Basketball Reference](http://www.basketball-reference.com) is a great site (especially for a basketball stats nut like me), and hopefully they don't get too pissed off at me for creating this.

I initially wrote this library as an exercise for creating my first `PyPi` package - hope you find it valuable!  

## Documentation

For documentation about installing the package and API methods see [the documentation page](https://jaebradley.github.io/basketball_reference_web_scraper/).

## Contributors

Thanks to [@DaiJunyan](https://github.com/DaiJunyan), [@ecallahan5](https://github.com/ecallahan5), 
[@Yotamho](https://github.com/Yotamho), and [@ntsirakis](https://github.com/ntsirakis) for their contributions!

==> basketball_reference_web_scraper-4.12.1.tar.gz: basketball_reference_web_scraper-4.12.1/README.md <==
<p align="center">
    <a href="#" target="_blank" rel="noopener noreferrer">
        <img width="550" src="https://imgur.com/dJL05Ud.png" alt="logo">
    </a>
</p>
<p align="center">
    <a href="https://pypi.org/project/basketball-reference-scraper/">
        <img src="https://img.shields.io/pypi/v/basketball_reference_web_scraper" alt="pypi" />
    </a>
    <a href="https://pypi.org/project/basketball-reference-scraper/">
        <img src="https://img.shields.io/pypi/pyversions/basketball_reference_web_scraper" alt="python version" />
    </a>
    <a href="https://pypi.org/project/basketball-reference-scraper/">
        <img src="https://img.shields.io/pypi/l/basketball_reference_web_scraper" alt="license" />
    </a>
    <a href="https://codecov.io/gh/jaebradley/basketball_reference_web_scraper">
        <img src="https://codecov.io/gh/jaebradley/basketball_reference_web_scraper/branch/v4/graph/badge.svg" alt="code coverage" />
    </a>
    <a href="https://github.com/jaebradley/basketball_reference_web_scraper/workflows/Basketball%20Reference%20Web%20Scraper/badge.svg">
        <img src="https://github.com/jaebradley/basketball_reference_web_scraper/workflows/Basketball%20Reference%20Web%20Scraper/badge.svg" alt="continuous integration" />
    </a>
</p>

[Basketball Reference](http://www.basketball-reference.com) is a great site (especially for a basketball stats nut like me), and hopefully they don't get too pissed off at me for creating this.

I initially wrote this library as an exercise for creating my first `PyPi` package - hope you find it valuable!  

## Documentation

For documentation about installing the package and API methods see [the documentation page](https://jaebradley.github.io/basketball_reference_web_scraper/).

## Contributors

Thanks to [@DaiJunyan](https://github.com/DaiJunyan), [@ecallahan5](https://github.com/ecallahan5), 
[@Yotamho](https://github.com/Yotamho), [@ntsirakis](https://github.com/ntsirakis), and [@allanbelliti](https://github.com/allanbelliti) for their contributions!
